# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.9.2~9615d2a',
    built_at='2024-09-06 11:26:31Z',
    sha='9615d2a3eac95e5f7abaea5a57f9d76db6f5a612',
    branch='HEAD',
    tag='v4.9.2',
)
